@@ -11,16 +11,16 @@ use Net::Write::Layer3;
 use Net::Frame::Simple;
 use Net::Frame::Dump::Online;
 
-use Net::Frame::IPv4;
-use Net::Frame::TCP;
+use Net::Frame::Layer::IPv4;
+use Net::Frame::Layer::TCP;
 
 my $oDevice = Net::Frame::Device->new(target => $target);
 
-my $ip4 = Net::Frame::IPv4->new(
+my $ip4 = Net::Frame::Layer::IPv4->new(
    src => $oDevice->ip,
    dst => $target,
 );
-my $tcp = Net::Frame::TCP->new(
+my $tcp = Net::Frame::Layer::TCP->new(
    dst     => $port,
    options => "\x02\x04\x54\x0b",
    payload => 'test',
